==> zend-framework_1.10.8.orig.tar.gz: zend-framework-1.10.8/tests/Zend/Log/Writer/ZendMonitorTest.php <==
<?php
/**
 * Zend Framework
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://framework.zend.com/license/new-bsd
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@zend.com so we can send you a copy immediately.
 *
 * @category   Zend
 * @package    Zend_Log
 * @subpackage UnitTests
 * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @version    $Id: ZendMonitorTest.php 22532 2010-07-07 02:32:08Z ramon $
 */

/** PHPUnit_Framework_TestCase */
require_once 'PHPUnit/Framework/TestCase.php';

/** Zend_Log_Writer_ZendMonitor */
require_once 'Zend/Log/Writer/ZendMonitor.php';

/**
 * @category   Zend
 * @package    Zend_Log
 * @subpackage UnitTests
 * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @group      Zend_Log
 */
class Zend_Log_Writer_ZendMonitorTest extends PHPUnit_Framework_TestCase
{
    /**
     * @group ZF-10081
     */
    public function testWrite()
    {
        $writer = new Zend_Log_Writer_ZendMonitor();
        $writer->write(array('message' => 'my mess', 'priority' => 1));
    }

    public function testFactory()
    {
        $cfg = array();

        $writer = Zend_Log_Writer_ZendMonitor::factory($cfg);
        $this->assertTrue($writer instanceof Zend_Log_Writer_ZendMonitor);
    }

    public function testIsEnabled()
    {
        $writer = new Zend_Log_Writer_ZendMonitor();
        $this->assertType('boolean', $writer->isEnabled());
    }
}

==> zend-framework_1.11.11.orig.tar.gz: zend-framework-1.11.11/tests/Zend/Log/Writer/ZendMonitorTest.php <==
<?php
/**
 * Zend Framework
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://framework.zend.com/license/new-bsd
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@zend.com so we can send you a copy immediately.
 *
 * @category   Zend
 * @package    Zend_Log
 * @subpackage UnitTests
 * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @version    $Id: ZendMonitorTest.php 23775 2011-03-01 17:25:24Z ralph $
 */

if (!defined('PHPUnit_MAIN_METHOD')) {
    define('PHPUnit_MAIN_METHOD', 'Zend_Log_Writer_ZendMonitorTest::main');
}

/** Zend_Log_Writer_ZendMonitor */
require_once 'Zend/Log/Writer/ZendMonitor.php';

/**
 * @category   Zend
 * @package    Zend_Log
 * @subpackage UnitTests
 * @copyright  Copyright (c) 2005-2011 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 * @group      Zend_Log
 */
class Zend_Log_Writer_ZendMonitorTest extends PHPUnit_Framework_TestCase
{
    public static function main()
    {
        $suite  = new PHPUnit_Framework_TestSuite(__CLASS__);
        $result = PHPUnit_TextUI_TestRunner::run($suite);
    }

    /**
     * @group ZF-10081
     */
    public function testWrite()
    {
        $writer = new Zend_Log_Writer_ZendMonitor();
        $writer->write(array('message' => 'my mess', 'priority' => 1));
    }

    public function testFactory()
    {
        $cfg = array();

        $writer = Zend_Log_Writer_ZendMonitor::factory($cfg);
        $this->assertTrue($writer instanceof Zend_Log_Writer_ZendMonitor);
    }

    public function testIsEnabled()
    {
        $writer = new Zend_Log_Writer_ZendMonitor();
        $this->assertType('boolean', $writer->isEnabled());
    }
}

if (PHPUnit_MAIN_METHOD == 'Zend_Log_Writer_ZendMonitorTest::main') {
    Zend_Log_Writer_ZendMonitorTest::main();
}
